/*:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::
::   Module      :   OS Interrupt Header
::   Copyright   :   (C)2003-2005 MotoTron Corporation
::   Platform(s) :   MPC5xx
::   Limitations :   MPC5xx OS
::
:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::*/

#ifndef __INTERUPT_H
#define __INTERUPT_H

/*----- INCLUDES ------------------------------------------------------------------------------------------*/
#include <TypeDefn.h>

/*----- DEFINES -------------------------------------------------------------------------------------------*/

/*----- TYPEDEFS ------------------------------------------------------------------------------------------*/

/*----- EXTERNALS -----------------------------------------------------------------------------------------*/

/*----- PROTOTYPES ----------------------------------------------------------------------------------------*/

/*********************************************************************
* asm void UNDISABLE(void)
* asm void DISABLE(void)
*
* Use SPR275 as a counter which records the number of times a
* DISABLE/UNDISABLE sequence has been called. Thus if DISABLE is
* called in a re-entrant module the UNDISABLE function will be able
* to unwind itself before finally re-enabling interrupts.
*
* PSEUSO CODE for DISABLE
* SPR275 += 1;
* Disable Interrupts by writing anything to SPR81
*
* PSEUSO CODE for UNDISABLE
* if (SPR275 != 0)
* {
*    SPR275 -= 1;
*    if (SPR275 == 0)
*    {
*       Re-enable interrupts by writing anything SPR80
*    }
* }
*
* ASSUMPTIONS
* Assumes that the setup code within the OSInit has zeroed SPR275
*
*********************************************************************/
asm void DISABLE(void)
{
%
    mtspr   81,r4
    mfspr   r4,275
    addi    r4,r4,1
    mtspr   275,r4
}

asm void UNDISABLE(void)
{
%lab end_undisable

    mfspr   r4,275
    cmplwi  r4,0
    beq     end_undisable
    addi    r4,r4,-1
    mtspr   275,r4
    cmplwi  r4,0
    bne     end_undisable
    mtspr   80,r4
end_undisable:
}

/* Function to set SPR275 for DISABLE/UNDISABLE use */
asm void SetupEnableDisable(void)
{
%
    li      r0,1
    mtspr   275,r0
}

asm uint4 SetupProcessState(void)
{
%
    li      r3,0
    mtspr   274, r3
}


/* Returns zero if the current Process is executing from the Background or Idle */
uint4 GetProcessState(void);

#endif /* __INTERUPT_H */

/*----- END OF FILE ---------------------------------------------------------------------------------------*/
