				
####################################################################################################
#
#   Module      :   MPC555 Linker Directive option file
#   Copyright   :   (C)2002 MotoTron Corporation
#   Platform(s) :   MPC555
#   Limitations :   NONE
#   $Workfile   :   MotoTron_MPC555_Heap.ld$
#
#---------------------------------------------------------------------------------------------------
#                  
#   This is the global Linker Directive file to be used with MPC555 based applications.
####################################################################################################

####################################################################################################
#   Setting up the Program Constants
####################################################################################################
CONSTANTS
{
    heap_reserve  = 4096
    tpustack_reserve = 2048
    boot_mailbox_reserve = 0x10
    soft_vectors_reserve = 0x40
    tpu_reserve  = 256
    prosak_read_reserve = 0xFF
    prosak_wr_16_reserve = 0xDF
    prosak_wr_8_reserve = 0x20
}


#############################################################################################################
#   Setting up the Program Sections and their placements
#############################################################################################################
MEMORY
{
    MODULECONFIG_SPACE    : ORIGIN = 0x00007000 ,     LENGTH = 0x00000FFF

    EXCEPTION_BRANCHTABLE : ORIGIN = 0x00008000 ,     LENGTH = 0x00000100
    APPLICATION_CRC       : ORIGIN = 0x00008100 ,     LENGTH = 0x00000008
    FLASH                 : ORIGIN = 0x00008108 ,     LENGTH = 0x00057EF8
    RAM                   : ORIGIN = 0x003F9800 ,     LENGTH = (26K - boot_mailbox_reserve - soft_vectors_reserve)  
    BOOT_MAILBOX_SPACE    : ORIGIN = 0x003FFFB0 ,     LENGTH = boot_mailbox_reserve
    SOFTVECTORS_SPACE     : ORIGIN = 0x003FFFC0 ,     LENGTH = soft_vectors_reserve
    
    TPU_A_SPACE           : ORIGIN = 0x00304100 ,     LENGTH = 256
    TPU_B_SPACE           : ORIGIN = 0x00304500 ,     LENGTH = 256
    EXTENDED_FLASH        : ORIGIN = 0x00800000 ,     LENGTH = 2048k
    EXTENDED_RAM          : ORIGIN = 0x02000000 ,     LENGTH = 1024k
    EXTENDED_RAM2         : ORIGIN = 0x01000000 ,     LENGTH = 512k
    EEPROM_SPACE          : ORIGIN = 0x00070000 ,     LENGTH = 8192
    PROSAK_SPACE          : ORIGIN = 0x00072000 ,     LENGTH = 0x00000204
    RUNTIME_STARTUP_STACK : ORIGIN = 0x00302000 ,     LENGTH = tpustack_reserve

#############################################################################################################
#    CAL SPACE is generated according to the Memory Layout pulldown option in the Target Definition Block
#------------------------------------------------------------------------------------------------------------
#    For a DEV configuration calibrations are placed at 0x00400000  ( default ) 
#    For a PROD configuration calibrations are placed at 0x00060000 
#############################################################################################################
    CAL_SPACE:            ORIGIN = 0x00060000 ,     LENGTH = 64K
}


#############################################################################################################
#    Setting up the Program Sections and their placements
#############################################################################################################
SECTIONS
{   
    .moduleconfig                                                           : > MODULECONFIG_SPACE

     ########################################################################################################
     # This is the start of the EXCEPTION_BRANCHTABLE section. It should be empty.
     ########################################################################################################
    .startofexcepttable                                   MAX_SIZE(0)       : > EXCEPTION_BRANCHTABLE
    .exceptionbranchtable                                                   : > EXCEPTION_BRANCHTABLE     
    .endofexcepttable             ALIGN(4)                MAX_SIZE(0)       : > EXCEPTION_BRANCHTABLE
     ########################################################################################################
     # This is the end of the EXCEPTION_BRANCHTABLE section. It should be empty.
     ########################################################################################################

    .applicationcrc                                                         : > APPLICATION_CRC     

     ########################################################################################################
     # This is the start of the FLASH section. It should be empty.
     ########################################################################################################
    .startofflash                                MAX_SIZE(0)                               : > FLASH

     ########################################################################################################
     # Further code sections go below this comment block :)
     ########################################################################################################
    .text                                                                                  : > FLASH
    .code                                                                                  : > FLASH
    .oscode                                                                                : > FLASH
    .fwcode                                                                                : > FLASH
    .utlcode                                                                               : > FLASH
    .beccode                                                                               : > FLASH
    .aeccode                                                                               : > FLASH
    .cvccode                                                                               : > FLASH
    .rodata                                                                                : > FLASH
    .sdata2                                                                                : > FLASH
    .rosdata                                                                               : > FLASH
    .constants                                                                             : > FLASH
    .osconstants                                                                           : > FLASH
    .fwconstants                                                                           : > FLASH
    .utlconstants                                                                          : > FLASH
    .becconstants                                                                          : > FLASH
    .aecconstants                                                                          : > FLASH
    .cvcconstants                                                                          : > FLASH
    .romdata        ROM(.data)                                                             : > FLASH
    .romsdata       ROM(.sdata)                                                            : > FLASH

    .secinfo                                                                               : > FLASH
    .fixtype                                                                               : > FLASH
    .fixaddr                                                                               : > FLASH
    .syscall                                                                               : > FLASH

#############################################################################################################
#   This is the end of the FLASH section. It should be empty. If a linker error, section limit exceeded, is
#   generated, it is because someone placed code in this section.
#------------------------------------------------------------------------------------------------------------
#   Further code sections go above this comment block :)
#############################################################################################################
    .endofflash         ALIGN(4)                MAX_SIZE(0)                                : > FLASH

    #########################################################################################################
    #   NOTE crc constants go OUTSIDE the flash area so that their contents are not included in the CRC calc
    #########################################################################################################
    .crcconstants       ALIGN(4)                                                           : > FLASH
    #########################################################################################################
    #   NOTE romcals go OUTSIDE the flash area so that their contents are not included in the CRC calc
    #########################################################################################################
    .romcals                                                                               : > FLASH
    #########################################################################################################
    #   NOTE the greenhills comment goes OUTSIDE so that date and time of the build don't affect the CRC (the
    #   same build environment built at a different time should give the same CRC value)
    #########################################################################################################
    .comment                                                                               : > FLASH

#############################################################################################################
#   This is the start of the TPU Parameter RAM section. It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startoftpuram                              MAX_SIZE(0)                          : > TPU_A_SPACE
#------------------------------------------------------------------------------------------------------------
#   Further TPU parameter RAM  sections go below this comment block :)
#############################################################################################################

    .tpuapararam                CLEAR           PAD(tpu_reserve)                     : > TPU_A_SPACE
    .tpubpararam                CLEAR           PAD(tpu_reserve)                     : > TPU_B_SPACE

#############################################################################################################
#   This is the end of the TPU Parameter RAM section.   It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further TPU parameter RAM  sections go above this comment block :)
#############################################################################################################
    .endoftpuram                                MAX_SIZE(0)                          : > TPU_B_SPACE

#############################################################################################################
#   This is the start of the RAM section.   It should be empty. If a linker error, section limit exceeded,
#   is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startofRAM                                 MAX_SIZE(0)                                  : > RAM
#------------------------------------------------------------------------------------------------------------
#   MUST KEEP the Following order of the default sections
#############################################################################################################
    .sdabase                                                                                 : > RAM
        .sbss                   CLEAR                                                        : > RAM
        .sdata                                                                               : > RAM
        .PPC.EMB.sbss0                                                                       : > RAM
        .PPC.EMB.sdata0                                                                      : > RAM

#############################################################################################################
#   This is the start of the Non-Zerovars RAM section. It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startofnonzerovars                         MAX_SIZE(0)                                  : > RAM
#------------------------------------------------------------------------------------------------------------
#   Non-zerovars sections do not get cleared (set to zero) as part of startup code
#   Further Non-Zerovars sections go below this comment block :)
#############################################################################################################
        .osnonzerovars          NOCLEAR                                                      : > RAM

#############################################################################################################
#   This is the end of the Non-Zerovars RAM section. It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further nonzerovars sections go above this comment block :)
#############################################################################################################
    .endofnonzerovars                           MAX_SIZE(0)                                  : > RAM
 
#############################################################################################################
#   This is the start of the Zerovars RAM section. It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startofzerovars                            MAX_SIZE(0)                                  : > RAM
#------------------------------------------------------------------------------------------------------------
#   zerovars sections get cleared (set to zero) as part of startup code
#   Further zerovars sections go below this comment :)
#############################################################################################################
    .bss                       CLEAR                                                         : > RAM
    .data                                                                                    : > RAM
    .zerovars                  CLEAR                                                         : > RAM
    .bss_zerovars              CLEAR                                                         : > RAM
    .ramcals                                                                                 : > RAM
    .oszerovars                CLEAR                                                         : > RAM
    .fwzerovars                CLEAR                                                         : > RAM
    .utlzerovars               CLEAR                                                         : > RAM
    .beczerovars               CLEAR                                                         : > RAM
    .aeczerovars               CLEAR                                                         : > RAM
    .cvczerovars               CLEAR                                                         : > RAM
    .ramkeepalive              CLEAR                                                         : > RAM
    .heap                      CLEAR ALIGN(4)   MIN_SIZE(heap_reserve)                       : > RAM
    .endofheap                                  MAX_SIZE(0)                                  : > RAM

#############################################################################################################
#   This is the end of the Zerovars RAM section.  It should be empty. If a linker error, section limit
#   exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further zerovars sections go above this comment block :)
#############################################################################################################
    .endofzerovars                                          MAX_SIZE(0)                      : > RAM 

#############################################################################################################
#   This is the end  of the RAM section.    It should be empty. If a linker error, section limit exceeded,
#   is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further TPU parameter RAM  sections go above this comment :)
#############################################################################################################
    .endofRAM                                MAX_SIZE(0)                                     : > RAM

#############################################################################################################
#   The following sections reserve RAM for the Stack and Soft Vectors.
#------------------------------------------------------------------------------------------------------------
# Set .stack symbol for the start-up code.  This uses tpu ram initially, until application has setup other 
# stacks.  TPU can be initialised after this.
    .startofruntimestack                     MAX_SIZE(0)			: > RUNTIME_STARTUP_STACK
    .stack				     MIN_SIZE(tpustack_reserve)		: > RUNTIME_STARTUP_STACK
    .endofruntimestack                       MAX_SIZE(0)			: > RUNTIME_STARTUP_STACK

    .bootmailbox                     NOCLEAR MIN_SIZE(boot_mailbox_reserve)     : > BOOT_MAILBOX_SPACE
    .softvectors                     CLEAR   MIN_SIZE(soft_vectors_reserve)     : > SOFTVECTORS_SPACE
#------------------------------------------------------------------------------------------------------------
#   The above sections do not get cleared (set to zero) as part of startup code since their content
#   will be assigned a value immediately after powerup reset.  
#############################################################################################################

#############################################################################################################
#   This is the start of the Extended RAM section.   It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startofExtendedRAM                      MAX_SIZE(0)                            : > EXTENDED_RAM
#------------------------------------------------------------------------------------------------------------
#   Further Extended RAM sections go below this comment block:)
#############################################################################################################

#############################################################################################################
#   This is the end  of the cal section.    It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further Extend RAM sections go above this comment block :)
#############################################################################################################
    .endofExtendedRAM                               MAX_SIZE(0)                     : > EXTENDED_RAM

    .startofExtendedRAM2                     MAX_SIZE(0)                           : > EXTENDED_RAM2
#No 555 module has this RAM so block others trying to declare in here
    .ExtendedRAM2_zerovars          NOCLEAR  MAX_SIZE(0)                           : > EXTENDED_RAM2
    .ExtendedRAM2_nonzerovars       NOCLEAR  MAX_SIZE(0)                           : > EXTENDED_RAM2
    .endofExtendedRAM2                       MAX_SIZE(0)                           : > EXTENDED_RAM2

#############################################################################################################
#   This is the start of the cal section. It should be empty. If a linker error, section limit exceeded, is
#   generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .startofcals                             MAX_SIZE(0)                               : > CAL_SPACE
#------------------------------------------------------------------------------------------------------------
#   Further cal sections go below this comment block:)
#############################################################################################################
    .cals                                                                              : > CAL_SPACE
    .oscals                                                                            : > CAL_SPACE
    .fwcals                                                                            : > CAL_SPACE
    .utlcals                                                                           : > CAL_SPACE
    .beccals                                                                           : > CAL_SPACE
    .aeccals                                                                           : > CAL_SPACE
    .cvccals                                                                           : > CAL_SPACE
#############################################################################################################
#   This is the end  of the cal section.    It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further cal sections go above this comment block :)
#############################################################################################################
    .endofcals          ALIGN(4)              MAX_SIZE(0)                               : > CAL_SPACE


#############################################################################################################
#   This is the start of the external flash sections. It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .ext_flash_start                                MAX_SIZE(0)                         : > EXTENDED_FLASH
#------------------------------------------------------------------------------------------------------------
#   Do not add further external flash memory blocks with non-zero sized sections as they are not programmed
#   when the module is programmed.
#############################################################################################################

#############################################################################################################
#   This is the start of the serialeeprom sections. It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .ee_spi_start                               MAX_SIZE(0)                         : > EEPROM_SPACE
#------------------------------------------------------------------------------------------------------------
#   Changing the order of these sections will impact on memfuncs.c
#   Further serialeeprom sections go below this comment block:)
#############################################################################################################

#############################################################################################################
#   This is the start of the Absolute Address sections.    It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .ee_abs_addr_start                          MAX_SIZE(0)                         : > EEPROM_SPACE 
#------------------------------------------------------------------------------------------------------------
#   The size of each Absolute Address section MUST be word aligned. The order of the sections MUST
#   be preserved. If a section is no longer is being used, the space that it is allocated becomes
#   dead space.
#   Further Absolute Address sections go below this comment block :)
#############################################################################################################
    .ee_testcode_status             MIN_SIZE(4) MAX_SIZE(4)                         : > EEPROM_SPACE
    .ee_mot_mfgr_data               MIN_SIZE(8) MAX_SIZE(8)                         : > EEPROM_SPACE
    .ee_app_status                  MIN_SIZE(4) MAX_SIZE(4)                         : > EEPROM_SPACE
    .ee_crypto                      MIN_SIZE(128)                                   : > EEPROM_SPACE
    .ee_prot_abs_word               MIN_SIZE(8) MAX_SIZE(8)                         : > EEPROM_SPACE
    .ee_prot_abs_os       ALIGN(4)  MIN_SIZE(final( sizeof(.ee_prot_abs_word) / 4)) : > EEPROM_SPACE
    .ee_prot_abs_os_prot  ALIGN(4)  MIN_SIZE(final( sizeof(.ee_prot_abs_word) ))    : > EEPROM_SPACE
                                                                
#############################################################################################################
#   This is the end  of the Absolute Address sections. It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further Absolute Address sections go above this comment block :)
#############################################################################################################
    .ee_abs_addr_end                  ALIGN(4)      MAX_SIZE(0)                     : > EEPROM_SPACE 

#############################################################################################################
#   This is the start of the Protected sections.    It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .ee_protected_start                      MAX_SIZE(0)                            : > EEPROM_SPACE 
#------------------------------------------------------------------------------------------------------------
#   The size of each protected section MUST be word aligned
#   DONT ADD FURTHER PROTECTED SECTIONS WITHOUT CHANGING THE OS TOO
#############################################################################################################

    .ee_prot_byte                  ALIGN(4)                                         : > EEPROM_SPACE
    .ee_prot_halfword              ALIGN(4)                                         : > EEPROM_SPACE
    .ee_prot_word                  ALIGN(4)                                         : > EEPROM_SPACE

#############################################################################################################
#   This is the end  of the Protected sections. It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   DONT ADD FURTHER PROTECTED SECTIONS WITHOUT CHANGING THE OS TOO
#############################################################################################################
    .ee_protected_end                        MAX_SIZE(0)                            : > EEPROM_SPACE 


#############################################################################################################
#   Sections needed to support the Protected Memory
#############################################################################################################
# ee_os_ptr size = size of ptr area
        .ee_os_ptr                 ALIGN(4)  MIN_SIZE(final(  sizeof(.ee_prot_byte)
                                                            + sizeof(.ee_prot_halfword)/2
                                                            + sizeof(.ee_prot_word)/4 ))  : > EEPROM_SPACE

# ee_os_prot is ee_os + size plus alignment to a word boundary
        .ee_os_prot                ALIGN(4)  MIN_SIZE(final(  sizeof(.ee_prot_byte)
                                                            + sizeof(.ee_prot_halfword)
                                                            + sizeof(.ee_prot_word) ))    : > EEPROM_SPACE
# Variables used in the control of the protected area.
        .ee_os_prot_ctrl                     MAX_SIZE(1)                                  : > EEPROM_SPACE


#############################################################################################################
#   This is the start of the standard sections. It should be empty. If a linker error, section limit exceeded
#   is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
    .ee_standard_start                       MAX_SIZE(0)                            : > EEPROM_SPACE 
#------------------------------------------------------------------------------------------------------------
#   Variables in this section are standard non-volatile variables
#   Further sections to go below this comment block:)
#############################################################################################################
    .ee_bss_CAN                                                                     : > EEPROM_SPACE
    .ee_data_CAN                                                                    : > EEPROM_SPACE
    .ee_bss_engcode                                                                 : > EEPROM_SPACE
    .ee_data_engcode                                                                : > EEPROM_SPACE
    .ee_bss_diag                                                                    : > EEPROM_SPACE
    .ee_data_diag                                                                   : > EEPROM_SPACE
#############################################################################################################
#   This is the end of the standard sections. It should be empty. If a linker error, section limit exceeded,
#   is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further standard sections go above this comment block :)
#############################################################################################################
    .ee_standard_end                         MAX_SIZE(0)                            : > EEPROM_SPACE 

#############################################################################################################
#   This is the end  of the serialeeprom sections.  It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further serialeeprom sections go above this comment block :)
#############################################################################################################
    .ee_spi_end                                 MAX_SIZE(0)                         : > EEPROM_SPACE

#############################################################################################################
#   This is the start of the PROSAK sections.   It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
        .prosak_start                                                               : > PROSAK_SPACE
#------------------------------------------------------------------------------------------------------------
#   Changing the order of these sections will impact on memfuncs.c
#   Further PROSAK sections go below this comment block:)
#############################################################################################################
        .prosak_read                            MIN_SIZE(prosak_read_reserve)       : > PROSAK_SPACE
        .prosak_wr_16                           MIN_SIZE(prosak_wr_16_reserve)      : > PROSAK_SPACE
        .prosak_wr_8                            MIN_SIZE(prosak_wr_8_reserve)       : > PROSAK_SPACE
#############################################################################################################
#   This is the end  of the PROSAK sections.    It should be empty. If a linker
#   error, section limit exceeded, is generated, it is because someone declared variables in this section.
#------------------------------------------------------------------------------------------------------------
#   Further PROSAK sections go above this comment block :)
#############################################################################################################
        .prosak_end             		MAX_SIZE(0)                         : > PROSAK_SPACE
#############################################################################################################
#   REQUIRED FOR GHS DEBUGGER
#------------------------------------------------------------------------------------------------------------
#  These special symbols mark the bounds of RAM and ROM memory.
#  They are used by the MULTI debugger.
#############################################################################################################
    __ghs_ramstart  = ADDR(.startofRAM);
    __ghs_ramend    = ADDR(.endofRAM);
    __ghs_romstart  = ADDR(.startofflash);
    __ghs_romend    = ADDR(.endofflash);
}

#############################################################################################################
#   Other linker options
#############################################################################################################
OPTION ("-u g_pCRCBlockPtr")
OPTION ("-u ExceptionBranchTable")


